@@ -14,14 +14,14 @@ def get_tooltip_data(word):
     with apsw.Connection(db) as connn:
         query = "SELECT * FROM morphology WHERE WordID=?" if word.startswith("wh") else "SELECT * FROM morphology WHERE WordID=? and Book > 39"
         cursor = connn.cursor()
-        cursor.execute(query, (int(word[2:]),))
+        cursor.execute(query, (int(word[2:] if word.startswith("wh") else word[1:]),))
         result = cursor.fetchone()    
     if result:
         wordID, clauseID, book, chapter, verse, word, lexicalEntry, morphologyCode, morphology, lexeme, transliteration, pronunciation, interlinear, translation, gloss = result
-        description = f'''<{'heb' if word.startswith("wh") else 'grk'}>{word}</{'heb' if word.startswith("wh") else 'grk'}> | <{'heb' if word.startswith("wh") else 'grk'}>{lexeme}</{'heb' if word.startswith("wh") else 'grk'}>
-{morphology}
-Interlinear: {interlinear}
-Translation: {translation}'''
+        description = f'''<{'heb' if word.startswith("wh") else 'grk'}>{word}</{'heb' if word.startswith("wh") else 'grk'}> | <{'heb' if word.startswith("wh") else 'grk'}>{lexeme}</{'heb' if word.startswith("wh") else 'grk'}><br>
+<clid>{morphology[:-1].replace(",", ", ")}</clid><br>
+<wgloss>{interlinear}</wgloss><br>
+<wtrans>{translation}</wtrans>'''
         #links = json.loads(links_json)
         return {'description': description, 'links': ""}
     return None
@@ -40,6 +40,7 @@ def page_home(
     pc: str | None = None, # primary color
     sc: str | None = None, # secondary color
     fs: int | None = None, # font size in %
+    s: bool | None = None, # sync
     d: bool | None = None, # dark mode
     t: str | None = None, # Token for using custom data: allow users to pass a custom token, which won't be stored, via a parameter when using public devices. For personal devices, enable persistent settings using `custom_token`.
     k: bool | None = True, # keep valid specified parameters in history
@@ -53,7 +54,9 @@ def page_home(
     tb: int | None = None, # tool book
     tc: int | None = None, # tool chapter
     tv: int | None = None, # tool verse
-    tool: str | None = None, # supported options: bible, ...
+    tool: str | None = None, # supported options: bible, audio, chronology, search ...
+    bq: str | None = None, # bible query; currently not in use
+    tq: str | None = None, # tool query
 ):
     """
     Home page that accepts optional parameters.
@@ -82,10 +85,16 @@ def page_home(
 
     # colors
     if pc:
-        app.storage.user["primary_colour"] = pc
+        app.storage.user["primary_color"] = pc
     if sc:
-        app.storage.user["secondary_colour"] = sc
-    ui.colors(primary=app.storage.user["primary_colour"], secondary=app.storage.user["secondary_colour"])
+        app.storage.user["secondary_color"] = sc
+    ui.colors(primary=app.storage.user["primary_color"], secondary=app.storage.user["secondary_color"])
+
+    # sync
+    if s is not None:
+        app.storage.user['sync'] = s
+    else:
+        s = app.storage.user.setdefault('sync', True)
 
     # Bind app state to user storage
     app.storage.user["fullscreen"] = False
@@ -105,7 +114,18 @@ def page_home(
     else:
         l = app.storage.user.setdefault('layout', 2)
 
+    if bq is not None:
+        app.storage.user['bible_query'] = bq
+    else:
+        bq = app.storage.user.setdefault('bible_query', '')    
+    if tq is not None:
+        app.storage.user['tool_query'] = tq
+    else:
+        tq = app.storage.user.setdefault('tool_query', '')
+
+    load_bible_at_start = False
     if bbt is not None:
+        load_bible_at_start = True
         app.storage.user['bible_book_text'] = bbt
     else:
         bbt = app.storage.user.setdefault('bible_book_text', "NET")
@@ -150,7 +170,7 @@ def page_home(
     gui.create_home_layout()
 
     # load bible content at start
-    if bb and bc and bv:
+    if load_bible_at_start:
         next_tab_num = gui.area1_tab_loaded + 1
         if next_tab_num > gui.area1_tab_counter:
             gui.add_tab_area1()
@@ -163,9 +183,54 @@ def page_home(
         next_tab_num = gui.area2_tab_loaded + 1
         if next_tab_num > gui.area2_tab_counter:
             gui.add_tab_area2()
-        gui.load_area_2_content(title=tbt if tool == "bible" else tool, keep=k)
+        gui.load_area_2_content(title=tbt if tool == "bible" else tool, keep=k, sync=s)
     elif not gui.area2_tab_loaded: # when nothing is loaded
-        ... # TODO - decides later
+        gui.load_area_2_content(title="Audio", sync=True)
+
+    if k:
+        # update storage based on latest loaded content
+        args = app.storage.user[gui.get_active_area1_tab()]
+        app.storage.user['bible_book_text'] = args.get('bt', "NET")
+        app.storage.user['bible_book_number'] = args.get('b', 1)
+        app.storage.user['bible_chapter_number'] = args.get('c', 1)
+        app.storage.user['bible_verse_number'] = args.get('v', 1)
+        app.storage.user['bible_query'] = args.get('q', '')
+
+        args = app.storage.user[gui.get_active_area2_tab()]
+        app.storage.user['tool_book_text'] = args.get('bt', "NET")
+        app.storage.user['tool_book_number'] = args.get('b', 1)
+        app.storage.user['tool_chapter_number'] = args.get('c', 1)
+        app.storage.user['tool_verse_number'] = args.get('v', 1)
+        app.storage.user['tool_query'] = args.get('q', '')
+    
+    if l is not None and l in (1, 2, 3):
+        gui.swap_layout(l)
+
+    # update the URL to reflect current settings without reloading
+    '''def update_url():
+        params = []
+        params.append(f'pc={app.storage.user["primary_color"]}')
+        params.append(f'sc={app.storage.user["secondary_color"]}')
+        params.append(f'fs={app.storage.user["font_size"]}')
+        params.append(f's={str(app.storage.user["sync"]).lower()}')
+        params.append(f'd={str(app.storage.user["dark_mode"]).lower()}')
+        if config.custom_token:
+            params.append(f't={config.custom_token}')
+        params.append(f'k={str(k).lower()}')
+        params.append(f'm={str(m).lower()}')
+        params.append(f'l={app.storage.user["layout"]}')
+        params.append(f'bbt={app.storage.user["bible_book_text"]}')
+        params.append(f'bb={app.storage.user["bible_book_number"]}')
+        params.append(f'bc={app.storage.user["bible_chapter_number"]}')
+        params.append(f'bv={app.storage.user["bible_verse_number"]}')
+        params.append(f'tbt={app.storage.user["tool_book_text"]}')
+        params.append(f'tb={app.storage.user["tool_book_number"]}')
+        params.append(f'tc={app.storage.user["tool_chapter_number"]}')
+        params.append(f'tv={app.storage.user["tool_verse_number"]}')
+        params.append(f'bq={app.storage.user["bible_query"]}')
+        params.append(f'tq={app.storage.user["tool_query"]}')
+        new_url = '/?' + '&'.join(params)
+        ui.run_javascript(f"history.replaceState(null, '', '{new_url}');")''' # TODO - update url when content is loaded
 
 # Settings
 @ui.page('/settings')
@@ -188,7 +253,7 @@ def page_Settings():
         ui.run_javascript(f"document.documentElement.style.fontSize = '{value}%'")
 
     # primary color
-    ui.colors(primary=app.storage.user["primary_colour"], secondary=app.storage.user["secondary_colour"])
+    ui.colors(primary=app.storage.user["primary_color"], secondary=app.storage.user["secondary_color"])
 
     # Bind app state to user storage
     ui.dark_mode().bind_value(app.storage.user, 'dark_mode')
@@ -214,11 +279,11 @@ def page_Settings():
                     .tooltip('Adjust the global font size (50% to 200%)')
                 # colors
                 ui.color_input(label='Primary Color') \
-                    .bind_value(app.storage.user, 'primary_colour') \
+                    .bind_value(app.storage.user, 'primary_color') \
                     .tooltip('Manual hex code or color picker for app theme.') \
                     .on_value_change(lambda e: ui.colors(primary=e.value))
                 ui.color_input(label='Secondary Color') \
-                    .bind_value(app.storage.user, 'secondary_colour') \
+                    .bind_value(app.storage.user, 'secondary_color') \
                     .tooltip('Manual hex code or color picker for app theme.') \
                     .on_value_change(lambda e: ui.colors(secondary=e.value))
                 # dark mode
