@@ -1,4 +1,4 @@
-import os, traceback
+import os, traceback, re
 from nicegui import app, ui
 from functools import partial
 
@@ -19,6 +19,7 @@ from biblemategui.pages.bibles.bible_translation import bible_translation
 
 from biblemategui.pages.tools.audio import bibles_audio
 from biblemategui.pages.tools.chronology import bible_chronology
+from biblemategui.pages.search.bible_verses import search_bible_verses
 
 class BibleMateGUI:
     def __init__(self):
@@ -234,9 +235,53 @@ class BibleMateGUI:
         """Get the currently active tab in Area 2"""
         return self.area2_tab_panels_container.value
 
+    def select_next_area1_tab(self):
+        if len(self.area1_tab_panels) == 1:
+            self.add_tab_area1()
+        else:
+            next_tab = False
+            while not next_tab:
+                for i in self.area1_tab_panels:
+                    if next_tab:
+                        self.area1_tab_panels_container.value = i
+                        return None
+                    elif i == self.area1_tab_panels_container.value:
+                        next_tab = True
+
+    def select_next_area2_tab(self):
+        if len(self.area2_tab_panels) == 1:
+            self.add_tab_area2()
+        else:
+            next_tab = False
+            while not next_tab:
+                for i in self.area2_tab_panels:
+                    if next_tab:
+                        self.area2_tab_panels_container.value = i
+                        return None
+                    elif i == self.area2_tab_panels_container.value:
+                        next_tab = True
+
+    def select_empty_area1_tab(self):
+        for child in self.area2_tabs:
+            if hasattr(child, '_props') and re.search("^Bible [0-9]", child._props.get('label', '')):
+                if tab_name := child._props.get('name', ''):
+                   self.area1_tab_panels_container.value = tab_name
+                   return None
+        self.add_tab_area1()
+
+    def select_empty_area2_tab(self):
+        for child in self.area2_tabs:
+            if hasattr(child, '_props') and re.search("^Tool [0-9]", child._props.get('label', '')):
+                if tab_name := child._props.get('name', ''):
+                   self.area2_tab_panels_container.value = tab_name
+                   return None
+        self.add_tab_area2()
+
     def get_content(self, title):
         if title.lower() == "audio":
             return bibles_audio
+        elif title.lower() == "search":
+            return search_bible_verses
         elif title.lower() == "chronology":
             return bible_chronology
         elif title == "ORB":
@@ -260,6 +305,10 @@ class BibleMateGUI:
 
     def load_area_1_content(self, content=None, title="Bible", tab=None, args=None, keep=True):
         """Load example content in the active tab of Area 1"""
+
+        if app.storage.user['layout'] == 3:
+            self.swap_layout(2)
+
         if content is None:
             content = self.get_content(title)
             if content is None:
@@ -269,16 +318,19 @@ class BibleMateGUI:
         try:
             # modify tab label here for particular features TODO
             tab_label = title
+            if not app.storage.user['bible_book_text'] == title:
+                app.storage.user['bible_book_text'] = title
             # Get the currently active tab
             active_tab = tab if tab else self.get_active_area1_tab()
             # args holder
             args = args if args else {
                 "title": title,
                 "label": tab_label,
-                "bt": app.storage.user.get('bible_book_text'),
-                "b": app.storage.user.get('bible_book_number'),
-                "c": app.storage.user.get('bible_chapter_number'),
-                "v": app.storage.user.get('bible_verse_number'),
+                "bt": app.storage.user.get('bible_book_text', "NET"),
+                "b": app.storage.user.get('bible_book_number', 1),
+                "c": app.storage.user.get('bible_chapter_number', 1),
+                "v": app.storage.user.get('bible_verse_number', 1),
+                "q": app.storage.user.get('bible_query', ''),
                 "area": 1,
                 "tab1": active_tab,
                 "tab2": self.get_active_area2_tab(),
@@ -287,25 +339,32 @@ class BibleMateGUI:
             active_panel = self.area1_tab_panels[active_tab]
             # Clear and load new content
             active_panel.clear()
+            # store as history
+            if keep:
+                app.storage.user[active_tab] = args
+            # load content
             with active_panel:
-                # load content here
                 content(gui=self, **args)
             # Update tab label to reflect new content
             for child in self.area1_tabs:
                 if hasattr(child, '_props') and child._props.get('name') == active_tab:
-                    # current label
-                    # print(child._props.get('label'))
                     child.props(f'label="{tab_label}"')
                     break
-            # store as history
-            if keep:
-                app.storage.user[active_tab] = args
         except:
             print(traceback.format_exc())
 
+    def is_tool(self, title):
+        tools = ("audio", "search", "chronology")
+        return True if title.lower() in tools else False
 
-    def load_area_2_content(self, content=None, title="Tool", tab=None, args=None, keep=True):
+    def load_area_2_content(self, content=None, title="Tool", tab=None, args=None, keep=True, sync=True):
         """Load example content in the active tab of Area 2"""
+
+        if app.storage.user['layout'] == 1:
+            self.swap_layout(2)
+
+        is_sync = True if sync or (sync and app.storage.user.get("sync") and not self.is_tool(title)) else False
+
         if content is None:
             content = self.get_content(title)
             if content is None:
@@ -322,9 +381,10 @@ class BibleMateGUI:
                 "title": title,
                 "label": tab_label,
                 "bt": app.storage.user.get('tool_book_text'),
-                "b": app.storage.user.get('bible_book_number') if app.storage.user.get("sync") else app.storage.user.get('tool_book_number'),
-                "c": app.storage.user.get('bible_chapter_number') if app.storage.user.get("sync") else app.storage.user.get('tool_chapter_number'),
-                "v": app.storage.user.get('bible_verse_number') if app.storage.user.get("sync") else app.storage.user.get('tool_verse_number'),
+                "b": app.storage.user.get('bible_book_number') if is_sync else app.storage.user.get('tool_book_number'),
+                "c": app.storage.user.get('bible_chapter_number') if is_sync else app.storage.user.get('tool_chapter_number'),
+                "v": app.storage.user.get('bible_verse_number') if is_sync else app.storage.user.get('tool_verse_number'),
+                "q": app.storage.user.get('tool_query', ''),
                 "area": 2,
                 "tab1": self.get_active_area1_tab(),
                 "tab2": active_tab,
@@ -333,32 +393,76 @@ class BibleMateGUI:
             active_panel = self.area2_tab_panels[active_tab]
             # Clear and load new content
             active_panel.clear()
+            # store as history
+            if keep:
+                app.storage.user[active_tab] = args
+            # load content
             with active_panel:
                 content(gui=self, **args)
             # Update tab label to reflect new content
             for child in self.area2_tabs:
                 if hasattr(child, '_props') and child._props.get('name') == active_tab:
-                    # current label
-                    # print(child._props.get('label'))
                     child.props(f'label="{tab_label}"')
                     break
-            # store as history
-            if keep:
-                app.storage.user[active_tab] = args
         except:
             print(traceback.format_exc())
 
-    def change_area_1_bible_chapter(self, version, book=1, chapter=1):
-        app.storage.user['bible_book_number']= book
-        app.storage.user['bible_chapter_number']= chapter
-        app.storage.user['bible_verse_number']= 1
-        self.load_area_1_content(title=version)
+    def change_area_1_bible_chapter(self, version, book=1, chapter=1, verse=1):
+        app.storage.user['bible_book_text'] = version
+        app.storage.user['bible_book_number'] = book
+        app.storage.user['bible_chapter_number'] = chapter
+        app.storage.user['bible_verse_number'] = verse
+        # in some cases, self.get_content do not work
+        if version == "ORB":
+            content = original_reader
+        elif version == "OIB":
+            content = original_interlinear
+        elif version == "OPB":
+            content = original_parallel
+        elif version == "ODB":
+            content = original_discourse
+        elif version == "OLB":
+            content = original_linguistic
+        else:
+            content = bible_translation
+        self.load_area_1_content(content=content, title=version)
+        if app.storage.user["sync"]:
+            args = app.storage.user[self.get_active_area2_tab()]
+            if not self.is_tool(args.get("title")) and (not args.get("b") == book or not args.get("c") == chapter):
+                self.change_area_2_bible_chapter(args.get("bt"), book, chapter, verse)
+                if config.reload_after_sync:
+                    ui.run_javascript('location.reload()')
 
-    def change_area_2_bible_chapter(self, version, book=1, chapter=1):
-        app.storage.user['bible_book_number']= book
-        app.storage.user['bible_chapter_number']= chapter
-        app.storage.user['bible_verse_number']= 1
-        self.load_area_2_content(title=version)
+    def change_area_2_bible_chapter(self, version, book=1, chapter=1, verse=1, sync=True):
+        app.storage.user['tool_book_text'] = version
+        if sync and app.storage.user.get("sync"):
+            app.storage.user['bible_book_number'] = book
+            app.storage.user['bible_chapter_number'] = chapter
+            app.storage.user['bible_verse_number'] = verse
+        else:
+            app.storage.user['tool_book_number'] = book
+            app.storage.user['tool_chapter_number'] = chapter
+            app.storage.user['tool_verse_number'] = verse
+        # in some cases, self.get_content do not work
+        if version == "ORB":
+            content = original_reader
+        elif version == "OIB":
+            content = original_interlinear
+        elif version == "OPB":
+            content = original_parallel
+        elif version == "ODB":
+            content = original_discourse
+        elif version == "OLB":
+            content = original_linguistic
+        else:
+            content = bible_translation
+        self.load_area_2_content(content=content, title=version, sync=sync)
+        if sync and app.storage.user["sync"]:
+            args = app.storage.user[self.get_active_area1_tab()]
+            if not args.get("b") == book or not args.get("c") == chapter:
+                self.change_area_1_bible_chapter(args.get("bt"), book, chapter, verse)
+                if config.reload_after_sync:
+                    ui.run_javascript('location.reload()')
 
     def add_tab_area1(self):
         """Dynamically add a new tab to Area 1"""
@@ -468,21 +572,13 @@ class BibleMateGUI:
                         icon='menu'
                     ).props('flat color=white').classes('lt-sm')
 
-                    # --- Mobile Avatar Button (Home) ---
-                    # This is a button that contains the avatar
-                    with ui.button(on_click=lambda: ui.navigate.to('/')).props('flat round dense').classes('lt-sm'):
-                        with ui.avatar(size='32px'):
-                            with ui.image(config.avatar if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')) as image:
-                                with image.add_slot('error'):
-                                    ui.icon('account_circle').classes('m-auto') # Center fallback icon
-
                     # --- Desktop Avatar + Title (Home) ---
                     # The button contains a row with the avatar and the label
                     with ui.button(on_click=lambda: ui.navigate.to('/')).props('flat text-color=white').classes('gt-xs'):
                         with ui.row().classes('items-center no-wrap'):
                             # Use a fallback icon in case the image fails to load
                             with ui.avatar(size='32px'):
-                                with ui.image(config.avatar if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')) as image:
+                                with ui.image(app.storage.user["avatar"] if app.storage.user["avatar"] else os.path.expanduser(config.avatar) if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')) as image:
                                     with image.add_slot('error'):
                                         ui.icon('account_circle').classes('m-auto') # Center fallback icon
                             
@@ -540,7 +636,7 @@ class BibleMateGUI:
                             ui.menu_item('Remove Tool Tab', on_click=self.remove_tab_area2)
                             ui.separator()
                             ui.menu_item('Bible Verse', on_click=lambda: self.load_area_2_content(self.work_in_progress))
-                            ui.menu_item('Bible Audio', on_click=lambda: self.load_area_2_content(title='Audio'))
+                            ui.menu_item('Bible Audio', on_click=lambda: self.load_area_2_content(title='Audio', sync=True))
                             ui.menu_item('Compare Chapter', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Compare Verse', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.separator()
@@ -559,7 +655,7 @@ class BibleMateGUI:
                     
                     with ui.button(icon='search').props('flat color=white round').tooltip('Search'):
                         with ui.menu():
-                            ui.menu_item('Bibles', on_click=lambda: self.load_area_2_content(self.work_in_progress))
+                            ui.menu_item('Bibles', on_click=lambda: self.load_area_2_content(title='Search'))
                             ui.menu_item('Parallels', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Promises', on_click=lambda: self.load_area_2_content(self.work_in_progress))
                             ui.menu_item('Topics', on_click=lambda: self.load_area_2_content(self.work_in_progress))
@@ -583,7 +679,22 @@ class BibleMateGUI:
                             ui.menu_item('Bible Only', on_click=lambda: self.swap_layout(1))
                             ui.menu_item('Tool Only', on_click=lambda: self.swap_layout(3))
                             ui.menu_item('Bible & Tool', on_click=lambda: self.swap_layout(2))
+                            # sync
+                            def toggleSync():
+                                app.storage.user["sync"] = not app.storage.user["sync"]
+                            with ui.row().tooltip('Toggle Bible Synchronization'):
+                                ui.menu_item('Sync', on_click=toggleSync)
+                                ui.space()
+                                ui.switch().bind_value(app.storage.user, 'sync')
                             ui.separator()
+                            # full screen
+                            def toggleFullscreen(): # ui.fullscreen().toggle does not work in this case
+                                app.storage.user["fullscreen"] = not app.storage.user["fullscreen"]
+                            with ui.row().tooltip('Toggle Fullscreen'):
+                                ui.menu_item('Fullscreen', on_click=toggleFullscreen)
+                                ui.space()
+                                ui.switch().bind_value(app.storage.user, 'fullscreen')
+                            # dark mode
                             with ui.menu_item() as dark_mode_menu_item:
                                 dark_mode_label = ui.label("Light Mode" if app.storage.user["dark_mode"] else "Dark Mode").classes('flex items-center')
                             def toggle_dark_mode_menu_item(text_label: ui.label):
@@ -591,11 +702,6 @@ class BibleMateGUI:
                                 #text_label.set_text("Light Mode" if app.storage.user["dark_mode"] else "Dark Mode")
                                 ui.run_javascript('location.reload()')
                             dark_mode_menu_item.on('click', lambda: toggle_dark_mode_menu_item(dark_mode_label))
-                            def toggleFullscreen(): # ui.fullscreen().toggle does not work in this case
-                                app.storage.user["fullscreen"] = not app.storage.user["fullscreen"]
-                            with ui.row():
-                                ui.menu_item('Fullscreen', on_click=toggleFullscreen)
-                                ui.switch().bind_value(app.storage.user, 'fullscreen')
                             ui.separator()
                             ui.menu_item('Preferences', on_click=lambda: ui.navigate.to('/settings'))
 
@@ -605,16 +711,22 @@ class BibleMateGUI:
                 .classes('lt-sm') \
                 .props('overlay') \
                 .bind_value(app.storage.user, 'left_drawer_open') as left_drawer:
-            
-            ui.label('Navigation').classes('text-xl')
 
-            # Home Link
-            ui.item('Home', on_click=lambda: (
-                ui.navigate.to('/'),
-                app.storage.user.update(left_drawer_open=False)
-            )).props('clickable')
-            ui.switch('Dark Mode').bind_value(app.storage.user, 'dark_mode').on_value_change(lambda: ui.run_javascript('location.reload()'))
+            # The button contains a row with the avatar and the label
+            with ui.button(on_click=lambda: ui.navigate.to('/')).props('flat text-color=white'):
+                with ui.row().classes('items-center no-wrap'):
+                    # Use a fallback icon in case the image fails to load
+                    with ui.avatar(size='32px'):
+                        with ui.image(app.storage.user["avatar"] if app.storage.user["avatar"] else os.path.expanduser(config.avatar) if config.avatar else os.path.join(BIBLEMATEGUI_APP_DIR, 'eliranwong.jpg')) as image:
+                            with image.add_slot('error'):
+                                ui.icon('account_circle').classes('m-auto') # Center fallback icon
+                    
+                    # This is just a label now; the parent button handles the click
+                    ui.label('BibleMate AI').classes('text-lg ml-2')
+
+            ui.switch('Sync').bind_value(app.storage.user, 'sync')
             ui.switch('Fullscreen').bind_value(app.storage.user, 'fullscreen')
+            ui.switch('Dark Mode').bind_value(app.storage.user, 'dark_mode').on_value_change(lambda: ui.run_javascript('location.reload()'))
 
             # Bibles
             with ui.expansion('Bibles', icon='local_library').props('header-class="text-secondary"'):
@@ -697,7 +809,7 @@ class BibleMateGUI:
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Bible Audio', on_click=lambda: (
-                    self.load_area_2_content(title='Audio'),
+                    self.load_area_2_content(title='Audio', sync=True),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Compare Chapter', on_click=lambda: (
@@ -745,7 +857,7 @@ class BibleMateGUI:
             # Search
             with ui.expansion('Search', icon='search').props('header-class="text-secondary"'):
                 ui.item('Bibles', on_click=lambda: (
-                    self.load_area_2_content(self.work_in_progress),
+                    self.load_area_2_content(title='Search'),
                     app.storage.user.update(left_drawer_open=False)
                 )).props('clickable')
                 ui.item('Parallels', on_click=lambda: (
@@ -809,7 +921,7 @@ class BibleMateGUI:
                 )).props('clickable')
 
             # Preferences
-            with ui.expansion('Settings', icon='auto_awesome').props('header-class="text-secondary"'):
+            with ui.expansion('Settings', icon='settings').props('header-class="text-secondary"'):
                 ui.item('Bible Only', on_click=lambda: (
                     self.swap_layout(1),
                     app.storage.user.update(left_drawer_open=False)
